function out_matrix = QPD_TransferMatrix(inBeamPath, z_in, g1, g2)
% function out_matrix = QPD_TransferMatrix(inBeamPath, z_in, g1, g2)
% 
% gives the transfer matrix assuming a ray vector at z_in,  as observecd by
% the displacement at "g1" and "g2",  assumed to be QPD1 and QPD2 unless
% specified.  Eg.
%
%  ( QPD1 )                (     x(z_in) )
%  (      ) = out_matrix * (             )
%  ( QPD2 )                ( theta(z_in) )
%
% Each QPD signal is normalized by the waist size at the detector: 
% 
%   QPD1 = QPD1_0 / omega_1
%
% where QPD1_0 is the displacement at the detector in meters and omega_1 is
% the waist size at the detector.
%
if ~exist('g1', 'var')
   g1 = 'QPD1';
   g2 = 'QPD2';
end
ABCD_qpd1 = inBeamPath.getTransferMatrix(z_in, inBeamPath.component(g1).z);
ABCD_qpd2 = inBeamPath.getTransferMatrix(z_in, inBeamPath.component(g2).z);
q_qpd1 = inBeamPath.qPropagate(inBeamPath.component(g1).z);
q_qpd2 = inBeamPath.qPropagate(inBeamPath.component(g2).z);

out_matrix = [ABCD_qpd1(1,:) / q_qpd1.waistSize; 
              ABCD_qpd2(1,:) / q_qpd2.waistSize];