% I start by assuming the waist is 2km down the arm,  and that the ITM and
% ETM table motions are independent (both reasonable assumptions

%% Calculate the cavity noise
load('PITCHmotion.mat');  % The ETM pitch motion from LisaB

ETMmot = PitchMot(1,:);
R_etm = 2245;
R_itm = 1934;
armlength = 3995;

waist_x = R_etm*ETMmot;          % waist displacement from etm lever arm

d_center = R_etm+R_itm - armlength;
waist_theta = sqrt(2)*waist_x/d_center;  % waist angle given by ROC center
                                         % shift relative to spacing. 
                                         % sqrt(2) from having two optics
waist = [waist_x; waist_theta];

%% Calculate the QPD shot noise
qpd_waist = 350e-6;                        % from TransmonTable.m
qpd_slope = sqrt(8/pi)/qpd_waist;    
qpd_I = 100e-3;                            % QPD total photocurrent
ec = 1.6e-19;                              % electron charge 
shotnoise_RIN = sqrt(2)* (qpd_I/ec)^(-1/2);  % sqrt(2) from two halves
x_sn = shotnoise_RIN/qpd_slope;  % this is about right for shot noise


%% Calculate the table motion
load('seismicX');      
x_table = interp1(freq, noiseX,f);
x_table(isnan(x_table)) = min(x_table);

rad_per_meter = 1;  
table = [x_table; rad_per_meter*x_table];  



      

%% 
% Now to turn this waist motion into motion at the table,  we need a ray
% tracing matrix.  We take this one from TransmonTable.m.
to_qpd = QPD_from_Arm;
tab_qpd = QPD_from_Table;

figure(1)
clf;
a = loglog(f, abs(to_qpd(1,1)*waist(1,:)), 'b-',...
       f, abs(to_qpd(1,2)*waist(2,:)), 'b--', ...
       f, abs(to_qpd(2,1)*waist(1,:)), 'r-', ...
       f, abs(to_qpd(2,2)*waist(2,:)), 'r--', ...
       f, abs(tab_qpd(1,1)*table(1,:)), 'c-', ...
       f, abs(tab_qpd(1,2)*table(2,:)), 'c--', ...
       f, abs(tab_qpd(2,1)*table(1,:)), 'm-', ...
       f, abs(tab_qpd(2,2)*table(2,:)), 'm--', ...
       f, ones(size(f))*x_sn/qpd_waist, 'g-', ...
       'LineWidth', 2);
a = legend( 'QPD1 cavity disp',  'QPD1 cavity angle', ...
       'QPD2 cavity disp', 'QPD2 cavity angle',...
       'QPD1 table disp', 'QPD1 table angle', ...
       'QPD2 table disp', 'QPD2 table angle', ...
       '"100mA Shot noise"');
set(a, 'FontSize', 14);
xlabel('Frequency [Hz]', 'FontSize', 16);
ylabel('Displacement at QPD [m/ \omega_{QPD}]', 'FontSize', 16);
set(gca, 'FontSize', 14);
axis([0.1 100 1e-10 1e-3])
title('QPD Signals', 'FontSize', 16);

%%
figure(2)

from_tab  = inv(to_qpd)*tab_qpd;
from_shot = inv(to_qpd)*x_sn/qpd_waist;

for ii = 1:2
    noise(ii,:) = sqrt( (from_tab(ii,1)*table(1,:)).^2 + ...
        (from_tab(ii,2)*table(2,:)).^2 + ...
        (from_shot(ii,1)).^2 + ...
        (from_shot(ii,2)).^2 );
end

loglog(f, noise(1,:), 'k-', ...
    f, 1e3*noise(2,:), 'k--', ...
     f, waist(1,:), 'r-', ...
    f, .9e3*waist(2,:), 'r--', ...
       'LineWidth', 2); 

axis([0.1 100 1e-12 1e-4])
             
a = legend('Disp. noise', 'Angle noise', ...
    'Disp. cavity', 'Angle cavity');
set(a, 'FontSize', 14);

xlabel('Frequency [Hz]', 'FontSize', 16);
ylabel('Waist motion  [m, mrad]', 'FontSize', 16);
set(gca, 'FontSize', 14);
title('Inferred cavity motion', 'FontSize', 16);

%% Required isolation

figure(3)
% the allowed table motion in order to be 5 times below the lowest cavity
% signal,  and 10 times lower than the shot noise.
qpdsusnoise = sqrt( (waist(1,:)*to_qpd(1,1)).^2/25  + x_sn.^2/100); 

invtab = inv(tab_qpd);
allowedtab = [ abs(qpdsusnoise*invtab(1,1));
    abs(qpdsusnoise*invtab(2,1))];
    
loglog(f, allowedtab(1,:)/sqrt(2), ...
       f, 1e3*allowedtab(2,:)/sqrt(2), ...
       f, table(1,:), ...
       f, table(2,:)*1e3,...
       'LineWidth', 2);
legend('Required Table Position', 'Required Table Angle', ...
    'Predicted ISI Position', 'Predicted ISI angle');
xlabel('Frequency [Hz]', 'FontSize', 16);
ylabel('Table motion  [m, mrad]', 'FontSize', 16);
set(gca, 'FontSize', 14);
title('Required table motion', 'FontSize', 16);
axis([0.1 100 1e-16 1e-6])

            
%% Starting signals
figure(4)
loglog(f, waist, f, ETMmot, 'LineWidth', 2);
legend('Displacement', 'Angle', 'ETM Pitch');
ylabel('Cavity motion [m, rad]');
xlabel('Frequency [Hz]');
axis([0.1 100 1e-14 1e-4]);

