function [gout, zout, fout] = gouyLengthScan(inBeamPath, dL, optic, g1, g2)
% function [gout, zout] = gouyLengthScan(inBeamPath, dL, optic, g1, g2)
%
% Scan the position of "optic" around its starting position by dL. "out" is
% the gouy separation between "g1" and "g2", which defaults to "qpd1" and
% "qpd2".  The output is the gouy phase output and the telescope waist 
% position "zout" and size "fout".

zStart = inBeamPath.component(optic).z;

if ~exist('g1', 'var')
    g1 = 'QPD1';
    g2 = 'QPD2';
end

zSecond = inBeamPath.component('Tel2').z;

for ii = 1:length(dL)
    inBeamPath.component(optic).z = zStart + dL(ii);
    gout(ii) = inBeamPath.gouySeperation(g1, g2, 'wrap');
    q = inBeamPath.qPropagate(zSecond+0.01);
    zout(ii) = q.waistZ;
    fout(ii) = q.waistSize;
end
inBeamPath.component(optic).z = zStart;
